@@ -27,6 +27,10 @@ try:
     from collections.abc import Sequence  # Python 3.3 and later
 except ImportError:
     from collections import Sequence
+try:
+    import numpy as np
+except ImportError:
+    np = None
 from collections import OrderedDict
 _id = 0
 
@@ -507,13 +511,25 @@ class DataMatrix(OrderedState):
             Sets columns in various formats. Is used by __setitem__ and
             __setattr__.
         """
-
+        
+        # Check if this is a valid column name
         if isinstance(name, bytes):
             name = safe_decode(name)
-        # Create a new column by type
-        if isinstance(value, type) and issubclass(value, BaseColumn):
-            self._cols[name] = value(self)
-            return
+        if not isinstance(name, str):
+            raise TypeError(u'Column names should be str, not %s' % type(name))
+        # Create a new column by column type:
+        # dm[name] = IntColumn
+        # dm[name] = float
+        if isinstance(value, type):
+            if value == int:
+                from datamatrix import IntColumn
+                value = IntColumn
+            elif value == float:
+                from datamatrix import FloatColumn
+                value = FloatColumn
+            if issubclass(value, BaseColumn):
+                self._cols[name] = value(self)
+                return
         # Create a new column by type, kwdict tuple
         if (
             isinstance(value, tuple) and
@@ -538,10 +554,24 @@ class DataMatrix(OrderedState):
                     u'Column should have the same length as the DataMatrix'
                 )
             self._cols[name] = value._empty_col(datamatrix=self)
-        if not isinstance(name, str):
-            raise TypeError(u'Column names should be str, not %s' % type(name))
         if name not in self:
-            self._cols[name] = self._default_col_type(self)
+            # Create a new SeriesColumn by assigning a 2D ndarray, but only if the
+            # column doesn't exist yet
+            if np is not None and isinstance(value, np.ndarray) and \
+                    len(value.shape) == 2:
+                if value.shape[0] == len(self):
+                    depth = value.shape[1]
+                elif value.shape[1] == len(self):
+                    depth = value.shape[0]
+                    value = np.swapaxes(value, 0, 1)
+                else:
+                    raise ValueError(
+                        'Invalid shape for SeriesColumn: {}'.format(
+                            value.shape))
+                from datamatrix import SeriesColumn
+                self[name] = SeriesColumn(depth=depth)
+            else:
+                self._cols[name] = self._default_col_type(self)
         self._cols[name][:] = value
         self._mutate()
 
@@ -558,7 +588,26 @@ class DataMatrix(OrderedState):
         if self._sorted:
             return list(sorted(seq, key=key))
         return list(seq)
+        
+    def _where(self, other_dm):
+        
+        """
+        visible: False
 
+        desc:
+            Returns the indices of other_dm in dm. This assumes that other_dm
+            is a subset of the current dm.
+        """
+        
+        if other_dm != self:
+            raise ValueError(
+                'Can only slice a DataMatrix with a subset of itself')
+        try:
+            return [self._rowid.index(rowid) for rowid in other_dm._rowid]
+        except KeyError:
+            raise ValueError(
+                'Can only slice a DataMatrix with a subset of itself')
+        
     # Implemented syntax
 
     def __hash__(self):
@@ -692,6 +741,8 @@ class DataMatrix(OrderedState):
                 from datamatrix import operations as ops
                 return ops.keep_only(self, *key)
             return self._slice(key)
+        if isinstance(key, DataMatrix):
+            return self._where(key)
         raise KeyError('Invalid key, index, or slice: %s' % key)
 
     def __str__(self):
